@@ -1,7 +1,10 @@
-from notecoin.huobi.constant import *
 from notecoin.huobi.model.market import *
-from notecoin.huobi.utils import *
-from notecoin.huobi.utils.input_checker import check_in_list
+from notecoin.huobi.service.market import (MarketService, MarketServiceSocket,
+                                           MarketServiceSub)
+from notecoin.huobi.utils.input_checker import (check_in_list, check_range,
+                                                check_should_not_none,
+                                                check_symbol,
+                                                check_symbol_list)
 
 
 class MarketClient(object):
@@ -16,6 +19,9 @@ class MarketClient(object):
             init_log: to init logger
         """
         self.__kwargs = kwargs
+        self.market_service = MarketService(**kwargs)
+        self.market_service_sub = MarketServiceSub(**kwargs)
+        self.market_service_socket = MarketServiceSocket(**kwargs)
 
     def get_candlestick(self, symbol, period, size=200):
         """
@@ -35,20 +41,21 @@ class MarketClient(object):
             "period": period,
             "size": size
         }
-        from huobi.service.market.get_candlestick import GetCandleStickService
-        return GetCandleStickService(params).request(**self.__kwargs)
+
+        return self.market_service.get_candle_stick_service(params)
 
     def sub_candlestick(self, symbols: 'str', interval: 'CandlestickInterval', callback, error_handler):
-
         """
-        Subscribe candlestick/kline event. If the candlestick/kline is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe candlestick/kline event. If the candlestick/kline is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param interval: The candlestick/kline interval, MIN1, MIN5, DAY1 etc.
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(candlestick_event: 'CandlestickEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+        between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
         :return: No return
@@ -63,14 +70,13 @@ class MarketClient(object):
             "symbol_list": symbol_list,
             "interval": interval,
         }
-
-        from huobi.service.market.sub_candlestick import SubCandleStickService
-        SubCandleStickService(params).subscribe(callback, error_handler, **self.__kwargs)
+        self.market_service_sub.sub_candle_stick_service(callback, error_handler, params)
 
     def req_candlestick(self, symbols: 'str', interval: 'CandlestickInterval', callback,
                         from_ts_second=None, end_ts_second=None, error_handler=None):
         """
-        Subscribe candlestick/kline event. If the candlestick/kline is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe candlestick/kline event. If the candlestick/kline is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param interval: The candlestick/kline interval, MIN1, MIN5, DAY1 etc.
@@ -79,7 +85,8 @@ class MarketClient(object):
                         pass
         :param from_ts_second : data from timestamp [it's second]
         :param end_ts_second : data util timestamp [it's second]
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+        between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
         :return: No return
@@ -96,18 +103,18 @@ class MarketClient(object):
             "from_ts_second": from_ts_second,
             "end_ts_second": end_ts_second
         }
+        self.market_service_socket.req_candle_stick_service(callback, error_handler, params)
 
-        from huobi.service.market.req_candlestick import ReqCandleStickService
-        ReqCandleStickService(params).subscribe(callback, error_handler, **self.__kwargs)
-
-    def get_pricedepth(self, symbol: 'str', depth_type: 'str', depth_size: 'int' = None) -> PriceDepth:
+    def get_price_depth(self, symbol: str, depth_type: str, depth_size: int = None) -> PriceDepth:
         """
         Get the Market Depth of a symbol.
 
         :param symbol: The symbol, like "btcusdt". (mandatory)
         :param depth_type: The tpye, like "step0" to "step5". (mandatory)
-        :param depth_size(optional): The maximum number of Market Depth step0 requested. range [1 - 150], default is 150
-                           The maximum number of Market Depth step1,step2,step3,step4,step5 requested. size is in [5, 10, 20], default is 20.
+        :param depth_size: (optional) The maximum number of Market Depth step0 requested. range [1 - 150],
+                           default is 150
+                           The maximum number of Market Depth step1,step2,step3,step4,step5 requested.
+                           size is in [5, 10, 20], default is 20.
         :return: Market Depth data.
         """
 
@@ -119,9 +126,7 @@ class MarketClient(object):
             "type": depth_type,
             # "depth": depth_size
         }
-
-        from huobi.service.market.get_pricedepth import GetPriceDepthService
-        ret_data = GetPriceDepthService(params).request(**self.__kwargs)
+        ret_data = self.market_service.get_price_depth_service(params)
 
         if depth_size is not None:
             if (ret_data.bids is not None) and (len(ret_data.bids) > depth_size):
@@ -149,16 +154,18 @@ class MarketClient(object):
         else:
             return defalut_value
 
-    def sub_pricedepth(self, symbols: 'str', depth_step: 'str', callback, error_handler=None):
+    def sub_price_depth(self, symbols: 'str', depth_step: 'str', callback, error_handler=None):
         """
-        Subscribe price depth event. If the price depth is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe price depth event. If the price depth is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param depth_step: The depth precision, string from step0 to step5.
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(price_depth_event: 'PriceDepthEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+                              between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
 
@@ -173,19 +180,19 @@ class MarketClient(object):
             "symbol_list": symbol_list,
             "step": new_step,
         }
-
-        from huobi.service.market.sub_pricedepth import SubPriceDepthService
-        SubPriceDepthService(params).subscribe(callback, error_handler, **self.__kwargs)
+        self.market_service_sub.sub_price_depth_service(callback, error_handler, params)
 
     def sub_pricedepth_bbo(self, symbols: 'str', callback, error_handler=None):
         """
-        Subscribe price depth event. If the price depth is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe price depth event. If the price depth is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(price_depth_event: 'PriceDepthEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+                              between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
 
@@ -198,20 +205,20 @@ class MarketClient(object):
         params = {
             "symbol_list": symbol_list,
         }
+        self.market_service_sub.sub_price_depth_bbo_service(callback, error_handler, params)
 
-        from huobi.service.market.sub_pricedepth_bbo import SubPriceDepthBboService
-        SubPriceDepthBboService(params).subscribe(callback, error_handler, **self.__kwargs)
-
-    def req_pricedepth(self, symbols: 'str', depth_step: 'str', callback, error_handler=None):
+    def req_price_depth(self, symbols: 'str', depth_step: 'str', callback, error_handler=None):
         """
-        Subscribe price depth event. If the price depth is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe price depth event. If the price depth is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param depth_step: The depth precision, string from step0 to step5.
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(price_depth_event: 'PriceDepthEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+                              between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
 
@@ -226,9 +233,7 @@ class MarketClient(object):
             "symbol_list": symbol_list,
             "step": new_step,
         }
-
-        from huobi.service.market.req_pricedepth import ReqPriceDepthService
-        ReqPriceDepthService(params).subscribe(callback, error_handler, **self.__kwargs)
+        self.market_service_socket.req_price_depth_service(callback, error_handler, params)
 
     def get_market_detail(self, symbol: 'str') -> MarketDetail:
         """
@@ -243,19 +248,19 @@ class MarketClient(object):
         params = {
             "symbol": symbol,
         }
-
-        from huobi.service.market.get_market_detail import GetMarketDetailService
-        return GetMarketDetailService(params).request(**self.__kwargs)
+        return self.market_service.get_market_detail_service(params)
 
     def sub_market_detail(self, symbols: 'str', callback, error_handler=None):
         """
-        Subscribe 24 hours trade statistics event. If statistics is generated, server will send the data to client and onReceive in callback will be called.
+        Subscribe 24 hours trade statistics event. If statistics is generated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(trade_statistics_event: 'TradeStatisticsEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+                              between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
         :return:  No return
@@ -267,19 +272,19 @@ class MarketClient(object):
         params = {
             "symbol_list": symbol_list,
         }
-
-        from huobi.service.market.sub_market_detail import SubMarketDetailService
-        SubMarketDetailService(params).subscribe(callback, error_handler, **self.__kwargs)
+        self.market_service_sub.sub_market_detail_service(callback, error_handler, params)
 
     def req_market_detail(self, symbols: 'str', callback, error_handler=None):
         """
-        Subscribe 24 hours trade statistics event. If statistics is generated, server will send the data to client and onReceive in callback will be called.
+        Subscribe 24 hours trade statistics event. If statistics is generated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(trade_statistics_event: 'TradeStatisticsEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+        between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
         :return:  No return
@@ -291,9 +296,7 @@ class MarketClient(object):
         params = {
             "symbol_list": symbol_list,
         }
-
-        from huobi.service.market.req_market_detail import ReqMarketDetailService
-        ReqMarketDetailService(params).subscribe(callback, error_handler, **self.__kwargs)
+        self.market_service_socket.req_market_detail_service(callback, error_handler, params)
 
     def get_market_trade(self, symbol: 'str') -> list:
         """
@@ -308,9 +311,7 @@ class MarketClient(object):
         params = {
             "symbol": symbol,
         }
-
-        from huobi.service.market.get_market_trade import GetMarketTradeService
-        return GetMarketTradeService(params).request(**self.__kwargs)
+        return self.market_service.get_market_trade_service(params)
 
     def get_history_trade(self, symbol: 'str', size: 'int' = None) -> list:
         """
@@ -328,19 +329,19 @@ class MarketClient(object):
             "symbol": symbol,
             "size": size
         }
-
-        from huobi.service.market.get_history_trade import GetHistoryTradeService
-        return GetHistoryTradeService(params).request(**self.__kwargs)
+        return self.market_service.get_history_trade_service(params)
 
     def sub_trade_detail(self, symbols: 'str', callback, error_handler=None):
         """
-        Subscribe price depth event. If the price depth is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe price depth event. If the price depth is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(trade_event: 'TradeEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error
+        happen between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
         :return:  No return
@@ -352,19 +353,19 @@ class MarketClient(object):
         params = {
             "symbol_list": symbol_list,
         }
-
-        from huobi.service.market.sub_trade_detail import SubTradeDetailService
-        SubTradeDetailService(params).subscribe(callback, error_handler, **self.__kwargs)
+        self.market_service_sub.sub_trade_detail_service(callback, error_handler, params)
 
     def req_trade_detail(self, symbols: 'str', callback, error_handler=None):
         """
-        Subscribe price depth event. If the price depth is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe price depth event. If the price depth is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(trade_event: 'TradeEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error
+        happen between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
         :return:  No return
@@ -376,18 +377,14 @@ class MarketClient(object):
         params = {
             "symbol_list": symbol_list,
         }
-
-        from huobi.service.market.req_trade_detail import ReqTradeDetailService
-        ReqTradeDetailService(params).subscribe(callback, error_handler, **self.__kwargs)
+        self.market_service_socket.req_trade_detail_service(callback, error_handler, params)
 
     def get_market_detail_merged(self, symbol):
         check_symbol(symbol)
         params = {
             "symbol": symbol
         }
-
-        from huobi.service.market.get_market_detail_merged import GetMarketDetailMergedService
-        return GetMarketDetailMergedService(params).request(**self.__kwargs)
+        return self.market_service.get_market_detail_merged_service(params)
 
     def get_market_tickers(self) -> list:
         """
@@ -397,8 +394,7 @@ class MarketClient(object):
         """
 
         params = {}
-        from huobi.service.market.get_market_tickers import GetMarketTickersService
-        return GetMarketTickersService(params).request(**self.__kwargs)
+        return self.market_service.get_market_tickers_service(params)
 
     """
     increase mbp(market by price)
@@ -406,14 +402,16 @@ class MarketClient(object):
 
     def sub_mbp_increase(self, symbols: 'str', levels: 'int', callback, error_handler=None):
         """
-        Subscribe mbp event. If the mbp is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe mbp event. If the mbp is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param levels: level, 5，10，20，150. current only support 150
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(price_depth_event: 'PriceDepthEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+        between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
 
@@ -429,9 +427,7 @@ class MarketClient(object):
             "symbol_list": symbol_list,
             "levels": levels
         }
-
-        from huobi.service.market.sub_mbp_increase import SubMbpIncreaseService
-        SubMbpIncreaseService(params).subscribe(callback, error_handler, **self.__kwargs)
+        return self.market_service_sub.sub_mbp_increase_service(callback, error_handler, params)
 
     """
     subscribe full mbp(market by price)
@@ -439,14 +435,16 @@ class MarketClient(object):
 
     def sub_mbp_full(self, symbols: 'str', levels: 'int', callback, error_handler=None):
         """
-        Subscribe full mbp event. If the mbp is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe full mbp event. If the mbp is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param levels: level, 5，10，20
         :param callback: The implementation is required. onReceive will be called if receive server's update.
             example: def callback(price_depth_event: 'PriceDepthEvent'):
                         pass
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+        between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
 
@@ -463,13 +461,12 @@ class MarketClient(object):
             "symbol_list": symbol_list,
             "levels": levels
         }
-
-        from huobi.service.market.sub_mbp_full import SubMbpFullService
-        SubMbpFullService(params).subscribe(callback, error_handler, **self.__kwargs)
+        self.market_service_sub.sub_mbp_full_service(callback, error_handler, params)
 
     def req_mbp(self, symbols: 'str', levels: 'int', callback, auto_close=True, error_handler=None):
         """
-        Subscribe mbp event. If the mbp is updated, server will send the data to client and onReceive in callback will be called.
+        Subscribe mbp event. If the mbp is updated,
+        server will send the data to client and onReceive in callback will be called.
 
         :param symbols: The symbols, like "btcusdt". Use comma to separate multi symbols, like "btcusdt,ethusdt".
         :param levels: level, 5，10，20，150. current only support 150
@@ -477,7 +474,8 @@ class MarketClient(object):
             example: def callback(price_depth_event: 'PriceDepthEvent'):
                         pass
         :param auto_close : close websocket connection after get data
-        :param error_handler: The error handler will be called if subscription failed or error happen between client and Huobi server
+        :param error_handler: The error handler will be called if subscription failed or error happen
+        between client and Huobi server
             example: def error_handler(exception: 'HuobiApiException')
                         pass
 
@@ -492,5 +490,4 @@ class MarketClient(object):
             "symbol_list": symbol_list,
             "levels": levels
         }
-        from huobi.service.market.req_mbp import ReqMbpService
-        ReqMbpService(params).subscribe(callback, error_handler, **self.__kwargs)
+        self.market_service_socket.req_mbp_service(callback, error_handler, params)
