@@ -11,6 +11,7 @@ from apscheduler.schedulers.blocking import BlockingScheduler
 from notecoin.huobi.constant import *
 from notecoin.huobi.constant import ApiVersion
 from notecoin.huobi.exception.huobi_api_exception import HuobiApiException
+from notecoin.huobi.model import Response
 from notecoin.huobi.utils import *
 from notecoin.huobi.utils.api_signature import create_signature_v2
 from notecoin.huobi.utils.etf_result import etf_result_check
@@ -85,14 +86,15 @@ def call_sync(request, is_checked=False):
         dict_data = json.loads(response.text, encoding="utf-8")
         # print("call_sync  === recv data : ", dict_data)
         check_response(dict_data)
-        return request.json_parser(dict_data)
+
+        return Response(dict_data=dict_data)
 
     elif request.method == "POST":
         response = session.post(request.host + request.url, data=json.dumps(request.post_body), headers=request.header)
         dict_data = json.loads(response.text, encoding="utf-8")
         # print("call_sync  === recv data : ", dict_data)
         check_response(dict_data)
-        return request.json_parser(dict_data)
+        return Response(dict_data=dict_data)
 
 
 def call_sync_perforence_test(request, is_checked=False):
