@@ -82,7 +82,8 @@ class MarketService(RestApiSyncClient):
         channel = "/market/tickers"
 
         def parse(dict_data):
-            return default_parse_list_dict(dict_data.get("data", []), MarketTicker)
+            return dict_data.get("data", [])
+            # return default_parse_list_dict(dict_data.get("data", []), MarketTicker)
 
         return self.request_process(HttpMethod.GET, channel, params, parse)
 
